@@ -21,8 +21,8 @@
 
 #include "syslogAnalyzer.h"
 
-#include <QStringList>
 #include <QDateTime>
+#include <QStringList>
 
 #include <KLocalizedString>
 
@@ -30,9 +30,9 @@
 #include "logging.h"
 
 #include "localLogFileReader.h"
+#include "logLevel.h"
 #include "logLine.h"
 #include "logMode.h"
-#include "logLevel.h"
 #include "logViewWidget.h"
 
 #include "logViewModel.h"
@@ -85,7 +85,7 @@ LogLine *SyslogAnalyzer::parseMessage(const QString &logLine, const LogFile &ori
         return undefinedLogLine(logLine, originalFile);
     }
 
-    int year = QDate::currentDate().year();
+    const int year = QDate::currentDate().year();
 
     // Month number
     QString month(logLine.left(3));
@@ -93,25 +93,25 @@ LogLine *SyslogAnalyzer::parseMessage(const QString &logLine, const LogFile &ori
     QString line(logLine);
 
     line.remove(0, 4);
-    int monthNum = ParsingHelper::instance()->parseSyslogMonth(month);
+    const int monthNum = ParsingHelper::instance()->parseSyslogMonth(month);
 
     // Day number
     QString day(line.left(2));
-    int dayNum = day.toInt();
+    const int dayNum = day.toInt();
 
     line.remove(0, 3);
 
     // Time
     QString stringTime(line.left(8));
-    int h = stringTime.leftRef(2).toInt();
+    const int h = stringTime.leftRef(2).toInt();
     stringTime.remove(0, 3);
-    int m = stringTime.leftRef(2).toInt();
+    const int m = stringTime.leftRef(2).toInt();
     stringTime.remove(0, 3);
-    int s = stringTime.leftRef(2).toInt();
+    const int s = stringTime.leftRef(2).toInt();
     stringTime.remove(0, 3);
 
-    QDateTime dateTime(QDate(year, monthNum, dayNum), QTime(h, m, s));
-    if (dateTime.isValid() == false) {
+    const QDateTime dateTime(QDate(year, monthNum, dayNum), QTime(h, m, s));
+    if (!dateTime.isValid()) {
         logDebug() << "Malformed date and time";
         return undefinedLogLine(logLine, originalFile);
     }
@@ -120,7 +120,7 @@ LogLine *SyslogAnalyzer::parseMessage(const QString &logLine, const LogFile &ori
 
     QString hostname;
 
-    int nextSpace = line.indexOf(QLatin1Char(' '));
+    const int nextSpace = line.indexOf(QLatin1Char(' '));
     int nextDoubleDot = line.indexOf(QLatin1Char(':'));
 
     // Normal case or no process name
@@ -146,8 +146,8 @@ LogLine *SyslogAnalyzer::parseMessage(const QString &logLine, const LogFile &ori
         process = line.left(nextDoubleDot);
 
         // If the delete process identifier option is enabled
-        if (KSystemLogConfig::deleteProcessIdentifier() == true) {
-            int squareBracket = process.indexOf(QLatin1Char('['));
+        if (KSystemLogConfig::deleteProcessIdentifier()) {
+            const int squareBracket = process.indexOf(QLatin1Char('['));
 
             // If we find a bracket, we remove the useless part
             if (squareBracket != -1) {
@@ -161,8 +161,7 @@ LogLine *SyslogAnalyzer::parseMessage(const QString &logLine, const LogFile &ori
     // If we can't find any ':' character, it means that this line is a
     // internal message of syslogd
     else {
-        if (line.contains(QLatin1String("last message repeated"))
-            || line.contains(QLatin1String("-- MARK --"))) {
+        if (line.contains(QLatin1String("last message repeated")) || line.contains(QLatin1String("-- MARK --"))) {
             process = QStringLiteral("syslog");
         } else {
             process = undefinedProcess();
@@ -176,16 +175,19 @@ LogLine *SyslogAnalyzer::parseMessage(const QString &logLine, const LogFile &ori
     list.append(process);
     list.append(message);
 
-    return new LogLine(logLineInternalIdGenerator++, dateTime, list, originalFile.url().toLocalFile(),
-                       originalFile.defaultLogLevel(), logMode);
+    return new LogLine(mLogLineInternalIdGenerator++, dateTime, list, originalFile.url().toLocalFile(), originalFile.defaultLogLevel(), mLogMode);
 }
 
 inline LogLine *SyslogAnalyzer::undefinedLogLine(const QString &message, const LogFile &originalFile)
 {
     QStringList items;
     items << undefinedHostName() << undefinedProcess() << message;
-    return new LogLine(logLineInternalIdGenerator++, QDateTime::currentDateTime(), items,
-                       originalFile.url().toLocalFile(), originalFile.defaultLogLevel(), logMode);
+    return new LogLine(mLogLineInternalIdGenerator++,
+                       QDateTime::currentDateTime(),
+                       items,
+                       originalFile.url().toLocalFile(),
+                       originalFile.defaultLogLevel(),
+                       mLogMode);
 }
 
 inline QString SyslogAnalyzer::undefinedHostName()
